// Edited 3/17/2015

/**************************************************************************/
/*!
    @file       Adafruit_ADS1015.h
    @author     K. Townsend (Adafruit Industries)
    @license    BSD (see LICENSE.txt)
    
    Ported to mbed by Arve Seljebu - arve0.github.io
 
    This is a library for the Adafruit ADS1015 breakout board
    ----> https://www.adafruit.com/products/1083
 
    Adafruit invests time and resources providing this open source code,
    please support Adafruit and open-source hardware by purchasing
    products from Adafruit!
 
    @section  HISTORY
 
    v1.0  - First release
    v1.1  - Added ADS1115 support - W. Earl
    v1.1.1  - Ported to mbed - Arve Seljebu
*/
/**************************************************************************/

#ifndef _ADAFRUIT_ADS1015_H
#define _ADAFRUIT_ADS1015_H

#include "simpletools.h"
#include "simplei2c.h" 
/*=========================================================================
    I2C ADDRESS/BITS
    -----------------------------------------------------------------------*/
    #define ADS1015_ADDRESS                 (0x48)    // 1001 000 (ADDR = GND)
/*=========================================================================*/
 
/*=========================================================================
    CONVERSION DELAY (in mS)
    -----------------------------------------------------------------------*/
    #define ADS1015_CONVERSIONDELAY         (1)
/*=========================================================================*/
 
/*=========================================================================
    POINTER REGISTER
    -----------------------------------------------------------------------*/
    #define ADS1015_REG_POINTER_CONVERT     (0x00)
    #define ADS1015_REG_POINTER_CONFIG      (0x01)
/*=========================================================================*/
 
/*=========================================================================
    CONFIG REGISTER
    -----------------------------------------------------------------------*/
    #define ADS1015_REG_CONFIG_OS_SINGLE    (0x8000)  // Write: Set to start a single-conversion
 
    #define ADS1015_REG_CONFIG_MUX_SINGLE_0 (0x4000)  // Single-ended AIN0
    #define ADS1015_REG_CONFIG_MUX_SINGLE_1 (0x5000)  // Single-ended AIN1
 
    #define ADS1015_REG_CONFIG_PGA_4_096V   (0x0200)  // +/-4.096V range = Gain 1
 
    #define ADS1015_REG_CONFIG_MODE_SINGLE  (0x0100)  // Power-down single-shot mode (default)
 
    #define ADS1015_REG_CONFIG_DR_1600SPS   (0x0080)  // 1600 samples per second - ADS1115 250SPS (default)
 
    #define ADS1015_REG_CONFIG_CMODE_TRAD   (0x0000)  // Traditional comparator with hysteresis (default)
 
    #define ADS1015_REG_CONFIG_CPOL_ACTVLOW (0x0000)  // ALERT/RDY pin is low when active (default)
 
    #define ADS1015_REG_CONFIG_CLAT_NONLAT  (0x0000)  // Non-latching comparator (default)
 
    #define ADS1015_REG_CONFIG_CQUE_NONE    (0x0003)  // Disable the comparator and put ALERT/RDY in high state (default)
/*=========================================================================*/
 
typedef struct
{
  double sample;
  double temp;

}LOOKUPTEMP;
 
    // Instance-specific properties
    uint8_t   m_i2cAddress;
    uint8_t   m_conversionDelay;
    uint8_t   m_bitShift;
    i2c*      m_i2c;
    extern    double extruder_celsius;
    extern    double bed_celsius;
 
    uint16_t  readADC_SingleEnded(uint8_t channel);
 
    uint16_t readRegister(uint8_t i2cAddress, uint8_t reg);
    void writeRegister(uint8_t i2cAddress, uint8_t reg, uint16_t value);
    
    void UpdateTemp(uint8_t channel);
    double lookupTemp(const LOOKUPTEMP *table, double sample);
    void adc_init(void);
    
#endif /* _ADAFRUIT_ADS1015_H */