#ifndef _CONFIG_H
#define _CONFIG_H

// Z Axis Assignments
#define Z_DISABLE 0
#define Z_STEP 1
#define Z_DIRECTION 2
#define Z_PULSE_WIDTH CLK_FREQ / 1000000 // 80
#define Z_MIN_SPEED CLK_FREQ / 5714 // 14000 Rounded
#define Z_MAZ_SPEED CLK_FREQ / 16000 // 5000
#define Z_RAMP_INC_DEC CLK_FREQ / 26666666 // 3 Rounded
#define Z_INC_DIR 0 // Counter-clockwise rotation
#define Z_DEC_DIR 1 // Clockwise rotation
#define Z_STEPS_PER_REV 2000 // 200 Full steps * 10 microsteps
#define Z_RAMPING_STEPS (Z_MIN_SPEED - Z_MAZ_SPEED) / Z_RAMP_INC_DEC
#define Z_TOTAL_RAMPING_STEPS Z_RAMPING_STEPS * 2
#define Z_MAZ_STEPS 16933 // 12 inches of linear travel
#define Z_STEPS_PER_MM 55.555 // Rounded

// ESTOP And Limit Switches Assignments
#define ESTOP_AND_LIMIT 3

// Serial LCD Display Assignment
#define SERIAL_LCD 4

// Homing Switch Assignments
#define X_HOMING 5
#define Y_HOMING 6
#define Z_HOMING 7

// Propeller Memory Card Assignments
#define DI 8 // IO0, DI, MOSI, CD Pin
#define DO 9 // IO1, DO, MISO Pin
#define WP 10 // IO2, WP Pin
#define HOLD 11 // IO3, HOLD Pin
#define SD_CS 12 // CS Pin For MicroSD Card Memory
#define FLASH_CS 13 // CS Pin For Flash Memory
#define SRAM_CS 14 // CS Pin For SRAM Memory
#define CLK 15 // CLK Pin

// Daughterboard Assignments
#define PLATFORM_HEATER 16
#define EXTRUDER_HEATER 17
#define EXTRUDER_FAN 18

// E Axis Assignments  
#define E_DIRECTION 19
#define E_STEP 20
#define E_DISABLE 21
#define E_PULSE_WIDTH CLK_FREQ / 1000000 // 80
#define E_MIN_SPEED CLK_FREQ / 5714 // 14000 Rounded
#define E_MAE_SPEED CLK_FREQ / 16000 // 5000
#define E_RAMP_INC_DEC CLK_FREQ / 26666666 // 3 Rounded
#define E_INC_DIR 0 // Counter-clockwise rotation
#define E_DEC_DIR 1 // Clockwise rotation
#define E_STEPS_PER_REV 2000 // 200 Full steps * 10 microsteps
#define E_RAMPING_STEPS (E_MIN_SPEED - E_MAE_SPEED) / E_RAMP_INC_DEC
#define E_TOTAL_RAMPING_STEPS E_RAMPING_STEPS * 2
#define E_MAE_STEPS 16933 // 12 inches of linear travel
#define E_STEPS_PER_MM 55.555 // Rounded

// X Axis Assignments  
#define X_DIRECTION 22
#define X_STEP 23
#define X_DISABLE 24
#define X_PULSE_WIDTH CLK_FREQ / 1000000 // 80
#define X_MIN_SPEED CLK_FREQ / 5714 // 14000 Rounded
#define X_MAX_SPEED CLK_FREQ / 16000 // 5000
#define X_RAMP_INC_DEC CLK_FREQ / 26666666 // 3 Rounded
#define X_INC_DIR 0 // Counter-clockwise rotation
#define X_DEC_DIR 1 // Clockwise rotation
#define X_STEPS_PER_REV 2000 // 200 Full steps * 10 microsteps
#define X_RAMPING_STEPS (X_MIN_SPEED - X_MAX_SPEED) / X_RAMP_INC_DEC
#define X_TOTAL_RAMPING_STEPS X_RAMPING_STEPS * 2
#define X_MAX_STEPS 16933 // 12 inches of linear travel
#define X_STEPS_PER_MM 55.555 // Rounded
  
// Y Axis Assignments
#define Y_DISABLE 25
#define Y_STEP 26  
#define Y_DIRECTION 27
#define Y_PULSE_WIDTH CLK_FREQ / 1000000 // 80
#define Y_MIN_SPEED CLK_FREQ / 5714 // 14000 Rounded
#define Y_MAX_SPEED CLK_FREQ / 16000 // 5000
#define Y_RAMP_INC_DEC CLK_FREQ / 26666666 // 3 Rounded
#define Y_INC_DIR 1 // Counter-clockwise rotation
#define Y_DEC_DIR 0 // Clockwise rotation
#define Y_STEPS_PER_REV 2000 // 200 Full steps * 10 microsteps
#define Y_RAMPING_STEPS (Y_MIN_SPEED - Y_MAX_SPEED) / Y_RAMP_INC_DEC
#define Y_TOTAL_RAMPING_STEPS Y_RAMPING_STEPS * 2
#define Y_MAX_STEPS 16933 // 12 inches of linear travel
#define Y_STEPS_PER_MM 55.555

// I2C Assignments
#define I2C_SCL 28
#define I2C_SDA 29

// Full Duplex Serial Assignments
#define TX 30
#define RX 31

#define DEBUG
#define GCODE_ELEMENTS 10

/** \def GCODE_TX
  Serial transmit output pin number.
*/
#define GCODE_TX 30 //Forger

/** \def GCODE_RX
  Serial receive input pin number.
*/
#define GCODE_RX 31 //Forger

/** \def GCODE_MODE
  Set/clear bits to define mode: 
  mode bit 0 = invert rx
  mode bit 1 = invert tx
  mode bit 2 = open-drain/source tx
  mode bit 3 = ignore tx echo on rx
*/
#define GCODE_MODE 0 //Forger

/** \def BAUD
  Rate binary values are transmitted, like 115200, 57600,..., 9600 etc.
*/
#define GCODE_BAUD 115200 //Forger

/** \def I2C_SCL
  Set the SCL pin for I2C communication 
*/
#define I2C_SCL 28

/** \def I2C_SDA
  Set the SDA pin for I2C communication
*/
#define I2C_SDA 29

/** \def I2C_MODE
  Sets the SCL drive mode:
  mode 0 = pulls the line high with pull-up resistor
  mode 1 = drives the line high with setting I/O pin to output.
*/
#define I2C_MODE 0

#define NUMSAMPLES 16 //Forger

#endif /* _CONFIG_H */